@@ -3,14 +3,12 @@
 Here are a collection of examples of how this module can be used.
 See the README or the natsort homepage for more details.
 """
-from __future__ import print_function, unicode_literals
 
 import os
 
 import pytest
 from natsort import natsort_key, natsort_keygen, natsorted, ns
 from natsort.compat.locale import get_strxfrm, null_string_locale
-from natsort.compat.py23 import PY_VERSION, py23_str
 
 
 @pytest.fixture
@@ -74,7 +72,7 @@ def test_natsort_keygen_returns_natsort_key_that_parses_input(alg, expected):
             ns.PATH | ns.GROUPLETTERS,
             (
                 (("", 6, "aA--", 5, "..", 34, "ee++", 1),),
-                ((2 * py23_str(os.sep),), ("fFoollddeerr  ((", 1, "))"), ("fFoooo",)),
+                ((2 * os.sep,), ("fFoollddeerr  ((", 1, "))"), ("fFoooo",)),
                 (("", 56.7),),
             ),
         ),
@@ -95,7 +93,6 @@ def test_natsort_keygen_handles_arbitrary_input(arbitrary_input, alg, expected):
         (ns.PATH | ns.GROUPLETTERS, ((b"6A-5.034e+1",),)),
     ],
 )
-@pytest.mark.skipif(PY_VERSION < 3.0, reason="special bytes handling only on Python3")
 def test_natsort_keygen_handles_bytes_input(bytes_input, alg, expected):
     ns_key = natsort_keygen(alg=alg)
     assert ns_key(bytes_input) == expected
@@ -152,19 +149,18 @@ def test_natsort_keygen_with_locale(mocker, arbitrary_input, alg, expected, is_d
             expected[1][1][i] = strxfrm(expected[1][1][i])
         expected = tuple(tuple(tuple(subsub) for subsub in sub) for sub in expected)
 
-    with mocker.patch("natsort.compat.locale.dumb_sort", return_value=is_dumb):
-        ns_key = natsort_keygen(alg=alg)
-        assert ns_key(arbitrary_input) == expected
+    mocker.patch("natsort.compat.locale.dumb_sort", return_value=is_dumb)
+    ns_key = natsort_keygen(alg=alg)
+    assert ns_key(arbitrary_input) == expected
 
 
 @pytest.mark.parametrize(
     "alg, is_dumb",
     [(ns.LOCALE, False), (ns.LOCALE, True), (ns.LOCALE | ns.CAPITALFIRST, False)],
 )
-@pytest.mark.skipif(PY_VERSION < 3.0, reason="special bytes handling only on Python3")
 @pytest.mark.usefixtures("with_locale_en_us")
 def test_natsort_keygen_with_locale_bytes(mocker, bytes_input, alg, is_dumb):
     expected = (b"6A-5.034e+1",)
-    with mocker.patch("natsort.compat.locale.dumb_sort", return_value=is_dumb):
-        ns_key = natsort_keygen(alg=alg)
-        assert ns_key(bytes_input) == expected
+    mocker.patch("natsort.compat.locale.dumb_sort", return_value=is_dumb)
+    ns_key = natsort_keygen(alg=alg)
+    assert ns_key(bytes_input) == expected
